]> git.mxchange.org Git - fba.git/commitdiff
Continued:
authorRoland Häder <roland@mxchange.org>
Sun, 21 May 2023 14:59:12 +0000 (16:59 +0200)
committerRoland Häder <roland@mxchange.org>
Sun, 21 May 2023 15:01:57 +0000 (17:01 +0200)
- res.reason is just a text respresentation of the code

fba.py
fetch_instances.py

diff --git a/fba.py b/fba.py
index 93a5de867ef99b8c5b889e432541d834bb05c62a..c48ac882b1bef716b245ee6d8b0b267bc031cd73 100644 (file)
--- a/fba.py
+++ b/fba.py
@@ -57,12 +57,11 @@ def update_last_blocked(domain: str):
         sys.exit(255)
 
 def update_last_error(domain: str, res: any):
-    # NOISY-DEBUG: print("DEBUG: domain,res.status_code", domain, res.status_code)
-
+    # NOISY-DEBUG: print("DEBUG: domain,res.status_code:", domain, res.status_code, res.reason)
     try:
         c.execute("UPDATE instances SET last_status_code = ?, last_error_details = ?, last_updated = ? WHERE domain = ?", [
             res.status_code,
-            res.text,
+            res.reason,
             time.time(),
             domain
         ])
@@ -73,7 +72,6 @@ def update_last_error(domain: str, res: any):
 
 def update_last_nodeinfo(domain: str):
     # NOISY-DEBUG: print("DEBUG: Updating last_nodeinfo for domain:", domain)
-
     try:
         c.execute("UPDATE instances SET last_nodeinfo = ?, last_updated = ? WHERE domain = ?", [
             time.time(),
@@ -108,8 +106,8 @@ def get_peers(domain: str) -> list:
     return peers
 
 def post_json_api(domain: str, path: str, data: str) -> list:
+    # NOISY-DEBUG: print("DEBUG: Sending POST to domain,path,data:", domain, path, data)
     try:
-        # NOISY-DEBUG: print("DEBUG: Sending POST to domain,path,data:", domain, path, data)
         res = reqto.post(f"https://{domain}{path}", data=data, headers=headers, timeout=config["timeout"])
 
         if not res.ok or res.status_code >= 400:
index 428533692764f8efeb96fc92861cae487ebfb3fe..5a9f5347edd5363d42ef5df04db4b3d4d3de9036 100644 (file)
@@ -55,7 +55,7 @@ fetch_instances(instance, None)
 
 # Loop through some instances
 fba.c.execute(
-    "SELECT domain FROM instances WHERE software IN ('pleroma', 'mastodon', 'friendica', 'misskey', 'gotosocial') AND (software IS NULL OR last_nodeinfo IS NULL OR last_nodeinfo < ?) ORDER BY rowid DESC", [time.time() - fba.config["recheck_instance"]]
+    "SELECT domain FROM instances WHERE software IN ('pleroma', 'mastodon', 'friendica', 'misskey', 'gotosocial') AND (last_nodeinfo IS NULL OR last_nodeinfo < ?) ORDER BY rowid DESC", [time.time() - fba.config["recheck_instance"]]
 )
 
 for instance in fba.c.fetchall():